==> bind9_9.16.0.orig.tar.xz: bind-9.16.0/bin/win32/BINDInstall/DirBrowse.h <==
/*
 * Portions Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * See the COPYRIGHT file distributed with this work for additional
 * information regarding copyright ownership.
 */

/*
 * Copyright (c) 1999-2000 by Nortel Networks Corporation
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND NORTEL NETWORKS DISCLAIMS
 * ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL NORTEL NETWORKS
 * BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 * SOFTWARE.
 */

#ifndef DIRBROWSE_H
#define DIRBROWSE_H

class CDirBrowse : public CDialog
{
	// Construction
      public:
	CDirBrowse(CString initialDir = "\\",
		   CWnd *  pParent = NULL); // standard constructor
	CString
	GetSelectedDir()
	{
		return (m_selectedDir);
	}

	//{{AFX_DATA(CDirBrowse)
	enum { IDD = IDD_BROWSE };
	// NOTE: the ClassWizard will add data members here
	//}}AFX_DATA

	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CDirBrowse)
      protected:
	virtual void
	DoDataExchange(CDataExchange *pDX); // DDX/DDV support
					    //}}AFX_VIRTUAL

      protected:
	// Generated message map functions
	//{{AFX_MSG(CDirBrowse)
	virtual BOOL
	OnInitDialog();
	afx_msg void
	OnDblclkDirlist();
	afx_msg void
	OnSelchangeDirlist();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()

      private:
	CString m_selectedDir;
};

#endif

==> bind-9.16.7.tar.xz: bind-9.16.7/bin/win32/BINDInstall/DirBrowse.h <==
/*
 * Portions Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * See the COPYRIGHT file distributed with this work for additional
 * information regarding copyright ownership.
 */

/*
 * Copyright (c) 1999-2000 by Nortel Networks Corporation
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND NORTEL NETWORKS DISCLAIMS
 * ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL NORTEL NETWORKS
 * BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 * SOFTWARE.
 */

#ifndef DIRBROWSE_H
#define DIRBROWSE_H

class CDirBrowse : public CDialog {
	/* Construction */
      public:
	CDirBrowse(CString initialDir = "\\",
		   CWnd *pParent = NULL); /* standard
					   * constructor
					   */
	CString
	GetSelectedDir() {
		return (m_selectedDir);
	}

	/*{{AFX_DATA(CDirBrowse) */
	enum { IDD = IDD_BROWSE };
	/* NOTE: the ClassWizard will add data members here */
	/*}}AFX_DATA */

	/* ClassWizard generated virtual function overrides */
	/*{{AFX_VIRTUAL(CDirBrowse) */
      protected:
	virtual void
	DoDataExchange(CDataExchange *pDX); /* DDX/DDV support */
					    /*}}AFX_VIRTUAL */

      protected:
	/* Generated message map functions */
	/*{{AFX_MSG(CDirBrowse) */
	virtual BOOL
	OnInitDialog();
	afx_msg void
	OnDblclkDirlist();
	afx_msg void
	OnSelchangeDirlist();
	/*}}AFX_MSG */
	DECLARE_MESSAGE_MAP()

      private:
	CString m_selectedDir;
};

#endif /* ifndef DIRBROWSE_H */
